==> langchain_openai-0.0.1-dev.6.tar.gz: lib/src/client/base.dart <==
import 'models/models.dart';

/// Base class for OpenAI API clients.
abstract interface class BaseOpenAIClient {
  /// Given a prompt, the model will return one or more predicted completions,
  /// and can also return the probabilities of alternative tokens at each
  /// position.
  ///
  /// See https://platform.openai.com/docs/api-reference/completions/create
  Future<OpenAICompletion> createCompletion({
    required final String model,
    required final List<String> prompts,
    final String? suffix,
    final int? maxTokens,
    final double? temperature,
    final double? topP,
    final int? n,
    final int? logprobs,
    final bool? echo,
    final List<String>? stop,
    final double? presencePenalty,
    final double? frequencyPenalty,
    final int? bestOf,
    final Map<String, dynamic>? logitBias,
    final String? user,
  });

  /// Given a list of messages describing a conversation, the model will return
  /// a response.
  ///
  /// See https://platform.openai.com/docs/api-reference/chat/create
  Future<OpenAIChatCompletion> createChatCompletion({
    required final String model,
    required final List<OpenAIChatCompletionMessage> messages,
    final List<OpenAIFunction>? functions,
    final OpenAIFunctionCall? functionCall,
    final int? maxTokens,
    final double? temperature,
    final double? topP,
    final int? n,
    final int? logprobs,
    final List<String>? stop,
    final double? presencePenalty,
    final double? frequencyPenalty,
    final Map<String, dynamic>? logitBias,
    final String? user,
  });

  /// Get a vector representation of a given input that can be easily consumed
  /// by machine learning models and algorithms.
  ///
  /// See https://platform.openai.com/docs/api-reference/embeddings
  Future<OpenAIEmbeddings> createEmbeddings({
    required final String model,
    required final dynamic input,
    final String? user,
  });
}

==> langchain_openai-0.0.8.tar.gz: lib/src/client/base.dart <==
import 'models/models.dart';

/// Base class for OpenAI API clients.
abstract interface class BaseOpenAIClient {
  /// Given a prompt, the model will return one or more predicted completions,
  /// and can also return the probabilities of alternative tokens at each
  /// position.
  ///
  /// See https://platform.openai.com/docs/api-reference/completions/create
  Future<OpenAICompletion> createCompletion({
    required final String model,
    required final List<String> prompts,
    final String? suffix,
    final int? maxTokens,
    final double? temperature,
    final double? topP,
    final int? n,
    final int? logprobs,
    final bool? echo,
    final List<String>? stop,
    final double? presencePenalty,
    final double? frequencyPenalty,
    final int? bestOf,
    final Map<String, dynamic>? logitBias,
    final String? user,
  });

  /// Given a list of messages describing a conversation, the model will return
  /// a response.
  ///
  /// See https://platform.openai.com/docs/api-reference/chat/create
  Future<OpenAIChatCompletion> createChatCompletion({
    required final String model,
    required final List<OpenAIChatCompletionMessage> messages,
    final List<OpenAIFunction>? functions,
    final OpenAIFunctionCall? functionCall,
    final int? maxTokens,
    final double? temperature,
    final double? topP,
    final int? n,
    final int? logprobs,
    final List<String>? stop,
    final double? presencePenalty,
    final double? frequencyPenalty,
    final Map<String, dynamic>? logitBias,
    final String? user,
  });

  /// Get a vector representation of a given input that can be easily consumed
  /// by machine learning models and algorithms.
  ///
  /// See https://platform.openai.com/docs/api-reference/embeddings
  Future<OpenAIEmbeddingsRequest> createEmbeddings({
    required final String model,
    required final dynamic input,
    final String? user,
  });
}
